==> hadoop-2.10.2-src.tar.gz: hadoop-2.10.2-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-common/src/main/java/org/apache/hadoop/yarn/server/federation/store/records/impl/pb/GetSubClustersInfoRequestPBImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership.  The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.hadoop.yarn.server.federation.store.records.impl.pb;

import org.apache.hadoop.classification.InterfaceAudience.Private;
import org.apache.hadoop.classification.InterfaceStability.Unstable;
import org.apache.hadoop.yarn.federation.proto.YarnServerFederationProtos.GetSubClustersInfoRequestProto;
import org.apache.hadoop.yarn.federation.proto.YarnServerFederationProtos.GetSubClustersInfoRequestProtoOrBuilder;
import org.apache.hadoop.yarn.server.federation.store.records.GetSubClustersInfoRequest;

import com.google.protobuf.TextFormat;

/**
 * Protocol buffer based implementation of {@link GetSubClustersInfoRequest}.
 */
@Private
@Unstable
public class GetSubClustersInfoRequestPBImpl extends GetSubClustersInfoRequest {

  private GetSubClustersInfoRequestProto proto =
      GetSubClustersInfoRequestProto.getDefaultInstance();
  private GetSubClustersInfoRequestProto.Builder builder = null;
  private boolean viaProto = false;

  public GetSubClustersInfoRequestPBImpl() {
    builder = GetSubClustersInfoRequestProto.newBuilder();
  }

  public GetSubClustersInfoRequestPBImpl(GetSubClustersInfoRequestProto proto) {
    this.proto = proto;
    viaProto = true;
  }

  public GetSubClustersInfoRequestProto getProto() {
    mergeLocalToProto();
    proto = viaProto ? proto : builder.build();
    viaProto = true;
    return proto;
  }

  private void mergeLocalToProto() {
    if (viaProto) {
      maybeInitBuilder();
    }
    mergeLocalToBuilder();
    proto = builder.build();
    viaProto = true;
  }

  private void maybeInitBuilder() {
    if (viaProto || builder == null) {
      builder = GetSubClustersInfoRequestProto.newBuilder(proto);
    }
    viaProto = false;
  }

  private void mergeLocalToBuilder() {
  }

  @Override
  public int hashCode() {
    return getProto().hashCode();
  }

  @Override
  public boolean equals(Object other) {
    if (other == null) {
      return false;
    }
    if (other.getClass().isAssignableFrom(this.getClass())) {
      return this.getProto().equals(this.getClass().cast(other).getProto());
    }
    return false;
  }

  @Override
  public String toString() {
    return TextFormat.shortDebugString(getProto());
  }

  @Override
  public boolean getFilterInactiveSubClusters() {
    GetSubClustersInfoRequestProtoOrBuilder p = viaProto ? proto : builder;
    return p.getFilterInactiveSubclusters();
  }

  @Override
  public void setFilterInactiveSubClusters(boolean filterInactiveSubClusters) {
    maybeInitBuilder();
    builder.setFilterInactiveSubclusters(filterInactiveSubClusters);
  }

}

==> hadoop-3.4.2-src.tar.gz: hadoop-3.4.2-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-common/src/main/java/org/apache/hadoop/yarn/server/federation/store/records/impl/pb/GetSubClustersInfoRequestPBImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership.  The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.hadoop.yarn.server.federation.store.records.impl.pb;

import org.apache.hadoop.classification.InterfaceAudience.Private;
import org.apache.hadoop.classification.InterfaceStability.Unstable;
import org.apache.hadoop.yarn.federation.proto.YarnServerFederationProtos.GetSubClustersInfoRequestProto;
import org.apache.hadoop.yarn.federation.proto.YarnServerFederationProtos.GetSubClustersInfoRequestProtoOrBuilder;
import org.apache.hadoop.yarn.server.federation.store.records.GetSubClustersInfoRequest;

import org.apache.hadoop.thirdparty.protobuf.TextFormat;

/**
 * Protocol buffer based implementation of {@link GetSubClustersInfoRequest}.
 */
@Private
@Unstable
public class GetSubClustersInfoRequestPBImpl extends GetSubClustersInfoRequest {

  private GetSubClustersInfoRequestProto proto =
      GetSubClustersInfoRequestProto.getDefaultInstance();
  private GetSubClustersInfoRequestProto.Builder builder = null;
  private boolean viaProto = false;

  public GetSubClustersInfoRequestPBImpl() {
    builder = GetSubClustersInfoRequestProto.newBuilder();
  }

  public GetSubClustersInfoRequestPBImpl(GetSubClustersInfoRequestProto proto) {
    this.proto = proto;
    viaProto = true;
  }

  public GetSubClustersInfoRequestProto getProto() {
    mergeLocalToProto();
    proto = viaProto ? proto : builder.build();
    viaProto = true;
    return proto;
  }

  private void mergeLocalToProto() {
    if (viaProto) {
      maybeInitBuilder();
    }
    mergeLocalToBuilder();
    proto = builder.build();
    viaProto = true;
  }

  private void maybeInitBuilder() {
    if (viaProto || builder == null) {
      builder = GetSubClustersInfoRequestProto.newBuilder(proto);
    }
    viaProto = false;
  }

  private void mergeLocalToBuilder() {
  }

  @Override
  public int hashCode() {
    return getProto().hashCode();
  }

  @Override
  public boolean equals(Object other) {
    if (other == null) {
      return false;
    }
    if (other.getClass().isAssignableFrom(this.getClass())) {
      return this.getProto().equals(this.getClass().cast(other).getProto());
    }
    return false;
  }

  @Override
  public String toString() {
    return TextFormat.shortDebugString(getProto());
  }

  @Override
  public boolean getFilterInactiveSubClusters() {
    GetSubClustersInfoRequestProtoOrBuilder p = viaProto ? proto : builder;
    return p.getFilterInactiveSubclusters();
  }

  @Override
  public void setFilterInactiveSubClusters(boolean filterInactiveSubClusters) {
    maybeInitBuilder();
    builder.setFilterInactiveSubclusters(filterInactiveSubClusters);
  }

}
